clear all;
addpath(getenv('KWAVE_ROOT'));

% create the computational grid
Nx = 64;
Ny = 128;
Nz = 256;
dx = 1.0e-4;
dy = 1.0e-4;
dz = 1.0e-4;
kgrid = makeGrid(Nx, dx, Ny, dy, Nz, dz);

% PML options
PML_size = 20;

% define the properties of the propagation medium
medium.sound_speed = 1500;
medium.density = 1000;

% create initial pressure distribution
source.p0 = zeros([Nx Ny Nz]);
source.p0(floor(Nx / 2) - 16 + 1 : floor(Nx / 2) + 16, floor(Ny / 2) - 16 + 1 : floor(Ny / 2) + 16, floor(Nz / 2) - 16 + 1 : floor(Nz / 2) + 16) = 1.0e3;

% smooth
source.p0 = smooth(kgrid, source.p0, true);

% define sensor mask
sensor.mask = zeros(Nx, Ny, Nz);
sensor.mask(:, :, floor(Nz/2) + 1) = 1;

dt = 0.3 * dx / medium.sound_speed;
t_end = ((Nx / 2) * dx) / medium.sound_speed;
kgrid.t_array = 0:dt:t_end;

% save the input file
filename = 'example_001_simple_p0_m.h5';
sensor_data = kspaceFirstOrder3D(kgrid, medium, source, sensor, 'PMLSize', 20, 'SaveToDisk', filename);
