clear all;
addpath(getenv('KWAVE_ROOT'));

% create the computational grid
Nx = 256;
Ny = 128;
Nz = 64;
dx = 1.0e-4;
dy = 1.0e-4;
dz = 1.0e-4;
kgrid = makeGrid(Nx, dx, Ny, dy, Nz, dz);

% PML options
PML_size = 20;

% define the properties of the propagation medium
medium.sound_speed = 1500;
medium.density = 1000;

dt = 0.3 * dx / 1500;
t_end = ((Nx / 2) * dx) / 1500;
kgrid.t_array = 0:dt:t_end;

% Define source shape as two planes in the domain
source.p_mask = zeros(Nx, Ny, Nz);
source.p_mask(floor(Nx / 4) + 1, ...
              floor(Ny / 2) - 16 + 1 : floor(Ny / 2) + 16, ...
              floor(Nz / 2) - 16 + 1 : floor(Nz / 2) + 16) = 1;
source.p_mask(end - floor(Nx / 4) + 1, ...
              floor(Ny / 2) - 16 + 1 : floor(Ny / 2) + 16, ...
              floor(Nz / 2) - 16 + 1 : floor(Nz / 2) + 16) = 1;

% Create sinusoidal source signal of 1 MHz and amplitude of 10 Pa
amplitude = 10;
frequency = 1.0e6;
source.p  = amplitude * sin(frequency * (2*pi) * (0:dt:t_end));

% define sensor mask
sensor.mask = zeros(Nx, Ny, Nz);
sensor.mask(:, :, floor(Nz/2) + 1) = 1;

% save the input file
filename = 'example_002_p_source_m.h5';
sensor_data = kspaceFirstOrder3D(kgrid, medium, source, sensor, 'PMLSize', 20, 'SaveToDisk', filename);
