clear all;
addpath(getenv('KWAVE_ROOT'));

% create the computational grid
Nx = 256;
Ny = 128;
Nz = 64;
dx = 1.0e-4;
dy = 1.0e-4;
dz = 1.0e-4;
kgrid = makeGrid(Nx, dx, Ny, dy, Nz, dz);

% PML options
PML_size = 20;

% define the properties of the propagation medium
medium.sound_speed = 1500;
medium.density = 1000;

dt = 0.3 * dx / medium.sound_speed;
t_end = ((Nx / 2) * dx) / medium.sound_speed;
kgrid.t_array = 0:dt:t_end;

% Define source shape as two planes in the domain
source.p_mask = zeros(Nx, Ny, Nz);
source.p_mask(floor(Nx / 4) + 1, ...
              floor(Ny / 2) - 16 + 1 : floor(Ny / 2) + 16, ...
              floor(Nz / 2) - 16 + 1 : floor(Nz / 2) + 16) = 1;
source.p_mask(end - floor(Nx / 4) + 1, ...
              floor(Ny / 2) - 16 + 1 : floor(Ny / 2) + 16, ...
              floor(Nz / 2) - 16 + 1 : floor(Nz / 2) + 16) = 2;
p_mask_non_zeros = nonzeros(source.p_mask);
source.p_mask(source.p_mask(:) ~= 0) = 1;

% Create sinusoidal source signal of 1 MHz and amplitude of 10 Pa
amplitude = 10;
frequency = 1.0e6;
signal    = amplitude * sin(frequency * (2*pi) * (0:dt:t_end));
source.p  = zeros(length(p_mask_non_zeros), length(signal));
source.p(p_mask_non_zeros(:) == 1, :) =  repmat(signal, [sum(p_mask_non_zeros(:) == 1) 1]);
source.p(p_mask_non_zeros(:) == 2, :) = -repmat(signal, [sum(p_mask_non_zeros(:) == 2) 1]);

% define sensor mask
sensor.mask = zeros(Nx, Ny, Nz);
sensor.mask(:, :, floor(Nz/2) + 1) = 1;

% save the input file
filename = 'example_003_p_source_many_m.h5';
sensor_data = kspaceFirstOrder3D(kgrid, medium, source, sensor, 'PMLSize', 20, 'SaveToDisk', filename);
