import sys
import numpy as np
import math

sys.path.append('..')

from kwave_input_file import KWaveInputFile
from kwave_data_filters import SpectralDataFilter

filename = 'example_003_p_source_many_py.h5'
grid_res = (1.0e-4, 1.0e-4, 1.0e-4)
grid_size = (256, 128, 64)

dt = 0.3 * grid_res[0] / 1500.0
end_time = ((grid_size[0] / 2) * grid_res[0]) / 1500.0
steps = int(end_time / dt)

with KWaveInputFile(filename, grid_size, steps, grid_res, dt) as file:
    file.write_medium_sound_speed(1500.0)
    file.write_medium_density(1000.0)

    # Define source shape as two planes in the domain
    source_mask = np.zeros(grid_size)
    source_mask[ int(grid_size[0] / 4),
                 int(grid_size[1] / 2 - 16): int(grid_size[1] / 2 + 16),
                 int(grid_size[2] / 2 - 16): int(grid_size[2] / 2 + 16)] = 1
    source_mask[-int(grid_size[0] / 4),
                 int(grid_size[1] / 2 - 16): int(grid_size[1] / 2 + 16),
                 int(grid_size[2] / 2 - 16): int(grid_size[2] / 2 + 16)] = 2

    # Define sinusoidal source signal of 1 MHz and amplitude of 10 Pa
    amplitude = 10
    frequency = 1.0e6
    source_signal = amplitude * np.sin(frequency * (2*math.pi) * np.arange(0.0, steps*dt, dt))

    # Retrieve list of non-zero values in the source mask in the order of indexes that will be used to define the source
    source_mask_non_zero = file.domain_mask_values_in_index_order(source_mask)
    # Allocate space for source series for each source grid-point
    source_signals = np.zeros((source_mask_non_zero.size, source_signal.size))
    # Using non-zero value positions we can identify each plane and assign appropriate signal series to its grid-points
    source_signals[source_mask_non_zero == 1, :] = source_signal
    source_signals[source_mask_non_zero == 2, :] = - source_signal

    # Finally write the source signals and source indexes to the input file
    file.write_source_input_p(file.domain_mask_to_index(source_mask), source_signals, KWaveInputFile.SourceMode.ADDITIVE, 1500.0)

    sensor_mask = np.zeros(grid_size)
    sensor_mask[:, :, int(grid_size[2] / 2)] = 1
    file.write_sensor_mask_index(file.domain_mask_to_index(sensor_mask))
